Rietveld Code Review Tool
Help | Bug tracker | Discussion group | Source code | Sign in
(2263)

Unified Diff: Lib/test/test_argparse.py

Issue 13041: argparse: terminal width is not detected properly
Patch Set: Created 1 year, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Please Sign in to add in-line comments.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Lib/argparse.py ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
--- a/Lib/test/test_argparse.py
+++ b/Lib/test/test_argparse.py
@@ -31,9 +31,9 @@
def setUp(self):
# The tests assume that line wrapping occurs at 80 columns, but this
# behaviour can be overridden by setting the COLUMNS environment
# variable. To ensure that this assumption is true, unset COLUMNS.
env = support.EnvironmentVarGuard()
- env.unset("COLUMNS")
+ env['COLUMNS'] = '80'
self.addCleanup(env.__exit__)
« no previous file with comments | « Lib/argparse.py ('k') | no next file » | no next file with comments »
@@ -31,9 +31,9 @@
# The tests assume that line wrapping occurs at 80 columns, but this
# behaviour can be overridden by setting the COLUMNS environment
- # variable. To ensure that this assumption is true, unset COLUMNS.
+ # variable. To ensure that this width is used, set COLUMNS=80.
env = support.EnvironmentVarGuard()

RSS Feeds Recent Issues | This issue
This is Rietveld cbc36f91f3f7